from setuptools import setup, find_packages

setup(
    name='forumPackage',
    version='0.3',
    packages=find_packages(exclude=['Test*']),
    license='MIT',
    description='A python package about forum',
    url='https://github.com/madison13g/Group-8-Step3',
    author='Amethyst He',
    author_email='hejinghongyue@outlook.com'
)